@@ -5,7 +5,7 @@ class Imp < Formula
   homepage 'https://integrativemodeling.org/'
   url 'https://integrativemodeling.org/2.8.0/download/imp-2.8.0.tar.gz'
   sha256 '83a23c56f0be9de8900d0edd3978eb8c2637e6d5086f7ef7e2cd61f0b7a5aa80'
-  revision 6
+  revision 7
 
   # Fix to work with latest CGAL (4.11)
   patch do
@@ -42,6 +42,9 @@ class Imp < Formula
     # Don't install in lib64 on Linux systems
     args << "-DCMAKE_INSTALL_LIBDIR=#{lib}"
     args << "-DCMAKE_INSTALL_PYTHONDIR=#{lib}/python#{pyver}/site-packages"
+    # Don't link against gperftools, even if they were found, since then the
+    # bottle won't work on systems without gperftools installed
+    args << "-DGPerfTools_found=0"
     mkdir "build" do
       system "cmake", *args
       system "make"
@@ -66,7 +69,12 @@ class Imp < Formula
   test do
     Language::Python.each_python(build) do |python, version|
       system python, "-c", "import IMP"
+      system python, "-c", "import IMP.em2d"
+      system python, "-c", "import IMP.foxs"
+      system python, "-c", "import IMP.multifit"
     end
+    system "multifit"
+    system "foxs"
   end
 
 end
